====
Cipr
====

Cipr makes it easier to develop and manage packages for the 
`Corona SDK <http://www.anscamobile.com/corona/>`_.

Installation
============

Cipr is developed with `Python <http://python.org/>`_. Currently Cipr only supports Mac OSX.

To install, use `pip install <http://pypi.python.org/pypi/pip>`_::

	pip install cipr

Tutorial
========

Initialize a projects::

    cd /path/to/project
    cipr init

Installing packages::

    cipr install git://github.com/six8/cipr.class.git
    cipr install git://github.com/six8/cipr.logging.git